@@ -71,6 +71,18 @@ html_dependency_tocify <- function() {
     stylesheet = "jquery.tocify.css")
 }
 
+# Create an HTML dependency for Pandoc code block accessibility
+html_dependency_accessible_code_block <- function() {
+  ver <- pandoc_version()
+  if (ver < '2.7.3' || ver > '2.9.2.1') return()
+  htmlDependency(
+    name = "accessible-code-block",
+    version = "0.0.1",
+    src = pkg_file("rmd/h/accessibility"),
+    script = "empty-anchor.js"
+  )
+}
+
 # Create an HTML dependency for FontAwesome
 #' @rdname html-dependencies
 #' @export
@@ -314,16 +326,15 @@ html_dependency_rsiframe <- function() {
   )
 }
 
-# Pandoc 2.8 added attributes on headers instead of their parent divs, and we
-# need to move the 'class' attribute from header to div (#1723)
-html_dependency_elevate_section_attrs <- function() {
-  if (pandoc_available('2.8')) list(
-    html_dependency_jquery(),
+# Pandoc 2.9 adds attributes on both headers and their parent divs. We remove
+# the ones on headers since they are unnecessary (#1723).
+html_dependency_header_attrs <- function() {
+  if (pandoc_available('2.9')) list(
     htmlDependency(
-      "elevate-section-attrs",
+      "header-attrs",
       version = packageVersion("rmarkdown"),
       src = pkg_file("rmd/h/pandoc"),
-      script = "elevate-section-attrs.js"
+      script = "header-attrs.js"
     )
   )
 }
